/**
 * @file
 * @brief Implementation of startup system task.
 */
#ifndef STA_RTOS2_STARTUP_HPP
#define STA_RTOS2_STARTUP_HPP

/**
 * @defgroup rtos2Startup Startup task
 * @ingroup rtos2API
 * @brief Startup system task.
 *
 * Check @ref rtos2BuildConfig for configuration options.
 */


#ifdef DOXYGEN
/**
 * @brief Enable module.
 *
 * @ingroup rtos2BuildConfig
 */
#  define STA_RTOS2_STARTUP_ENABLE
#endif // DOXYGEN


/**
 * @def STA_RTOS2_STARTUP_ENTRY_FUNCTION
 * @brief Set name of startup task entry function.
 *
 * @ingroup rtos2BuildConfig
 */
#ifndef STA_RTOS2_STARTUP_ENTRY_FUNCTION
#  define STA_RTOS2_STARTUP_ENTRY_FUNCTION startupTask
#endif // !STA_RTOS2_STARTUP_ENTRY_FUNCTION


#include <sta/config.hpp>
#ifdef STA_RTOS2_STARTUP_ENABLE


namespace sta
{
	/**
	 * @brief Extra initialization run at start of startup task.
	 *
	 * May be overridden by application if required.
	 *
	 * @ingroup rtos2Startup
	 */
	void startupExtras(void * argument);
} // namespace sta


#endif // STA_RTOS2_STARTUP_ENABLE

#endif // STA_RTOS2_STARTUP_HPP
